function ADS_func(switch_model)
%The function to create and run the ADS dynare codes
%Input:     switch_model: 'ADS_SIR' for SIR epidemic
%                         'ADS_SIR' for SIS epidemic
%                         'ADS_SAIR' for SAIR epidemic
%                         'ADS_SIRS' for SIRS epidemic
%Uses:      ADS_SIR_int: to calculate initial conditions of the SIR model
%           ADS_SIS_int: to calculate initial conditions of the SIS model
%           ADS_SAIR_int: to calculate initial conditions of the SAIR model
%           ADS_SIRS_int: to calculate initial conditions of the SIRS model
%           ADS_SIR_end: to calculate end conditions (steady state) of the SIR model
%           ADS_SIS_end: to calculate end conditions (steady state) of the SIS model
%           ADS_SAIR_end: to calculate end conditions (steady state) of the SAIR model
%           ADS_SIRS_end: to calculate end conditions (steady state) of the SIRS model

%Calculate the steady state and loading the parameters and variables
switch switch_model
    case 'ADS_SIR' 
        run ADS_SIR/ADS_SIR_init.m;
        load Settings/ADS_SIR_init.mat params SIR_vars_init SIR_varexo_init;
        run epi_models/epi_SIR.m;
        load Settings/SIR.mat Y_SIR_eu;
        run ADS_SIR/ADS_SIR_end.m;
        load Settings/ADS_SIR_end.mat params SIR_vars_end SIR_varexo_end;
        vars_names      =   fieldnames(SIR_vars_init);    %cell array of variable names
        varexo_names    =   fieldnames(SIR_varexo_init);  %cell array of exogenous variable names

    case 'ADS_SIS'  
        run ADS_SIS/ADS_SIS_init.m;
        load Settings/ADS_SIS_init.mat params SIS_vars_init SIS_varexo_init;
        run epi_models/epi_SIS.m;
        load Settings/SIS.mat Y_SIS_eu;
        run ADS_SIS/ADS_SIS_end.m;
        load Settings/ADS_SIS_end.mat params SIS_vars_end SIS_varexo_end;
        vars_names      =   fieldnames(SIS_vars_init);    %cell array of variable names
        varexo_names    =   fieldnames(SIS_varexo_init);  %cell array of exogenous variable names
        
    case 'ADS_SAIR'  
        run ADS_SAIR/ADS_SAIR_init.m;
        load Settings/ADS_SAIR_init.mat params SAIR_vars_init SAIR_varexo_init;
        run epi_models/epi_SAIR.m;
        load Settings/SAIR.mat Y_SAIR_eu;
        run ADS_SAIR/ADS_SAIR_end.m;
        load Settings/ADS_SAIR_end.mat params SAIR_vars_end SAIR_varexo_end;
        vars_names      =   fieldnames(SAIR_vars_init);    %cell array of variable names
        varexo_names    =   fieldnames(SAIR_varexo_init);  %cell array of exogenous variable names
    
    case 'ADS_SIRS'  
        run ADS_SIRS/ADS_SIRS_init.m;
        load Settings/ADS_SIRS_init.mat params SIRS_vars_init SIRS_varexo_init;
        run epi_models/epi_SIRS.m;
        load Settings/SIRS.mat Y_SIRS_eu;
        run ADS_SIRS/ADS_SIRS_end.m;
        load Settings/ADS_SIRS_end.mat params SIRS_vars_end SIRS_varexo_end;
        vars_names      =   fieldnames(SIRS_vars_init);    %cell array of variable names
        varexo_names    =   fieldnames(SIRS_varexo_init);  %cell array of exogenous variable names
end;
        
params_names    =   fieldnames(params);  %cell array of parameter names

nn_params       =   length(params_names);   %number of parameters
nn_vars         =   length(vars_names);     %number of endogenous variables
nn_varexo       =   length(varexo_names);   %number of exogenous variables

%Creating a string with the parameter names
params_string   =   [];
for ii=1:nn_params
    params_string   =   [params_string params_names{ii} ' '];
end;

vars_string     =   [];
for ii=1:nn_vars
    vars_string     =   [vars_string vars_names{ii} ' '];
end;

varexo_string     =   [];
for ii=1:nn_varexo
    varexo_string     =   [varexo_string varexo_names{ii} ' '];
end;

%Creating dynare file
cd dynare;

%Creating the '.mod' file and starting writing in it
eval(['fid  =   fopen(''' switch_model '.mod'',''w'');']);

fprintf(fid,'// Dynare model file ADS Model 2020 \n');
fprintf(fid,'// Created by Veronica Acurio Vasconez \n');
fprintf(fid,'// June 2020\n\n');

fprintf(fid,'// Variables \n\n');
fprintf(fid,['var ' vars_string ';\n\n']);
fprintf(fid,'predetermined_variables K;\n\n');

fprintf(fid,'// Exogenous Variables \n\n');
fprintf(fid,['varexo ' varexo_string ';\n\n']);

fprintf(fid,'// Parameters \n\n');
fprintf(fid,['parameters ' params_string ';\n']);

fprintf(fid,'\n\n');

%Writing the parameter values
for ii=1:nn_params
    eval(['fprintf(fid,''' params_names{ii} '=%2.8f;\n'',' 'params.' params_names{ii} ');']);
end;


%Opening the model file and copying the model into the dynare file
fprintf(fid,'\n\nmodel;\n');
fprintf(fid,'\n');

%Opening the model file as readable
eval(['fid_mod     =   fopen(''../' switch_model '/' switch_model '_model.m'',''r'');']);

while (1>0)
    modelline = fgetl(fid_mod);
        if (modelline==-1)  %end of file
            break 
        end;
    fprintf(fid,[modelline '\n']);
end;
fprintf(fid,'end;\n');
fclose(fid_mod);        %closing the model file

%Writing initial conditions
fprintf(fid,'\n\ninitval;\n');

switch switch_model    
    case 'ADS_SIR' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SIR_vars_init.' vars_names{ii} ');'])
        end;
    
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SIR_varexo_init.' varexo_names{ii} ');']);
        end;
        
    case 'ADS_SIS' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SIS_vars_init.' vars_names{ii} ');'])
        end;
        
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SIS_varexo_init.' varexo_names{ii} ');']);
        end;
        
    case 'ADS_SAIR' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SAIR_vars_init.' vars_names{ii} ');'])
        end;
    
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SAIR_varexo_init.' varexo_names{ii} ');']);
        end;
        
    case 'ADS_SIRS' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SIRS_vars_init.' vars_names{ii} ');'])
        end;
    
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SIRS_varexo_init.' varexo_names{ii} ');']);
        end;
end;

fprintf(fid,'end;\n');  %ending it

        
%Writing end conditions (assumed to be steady state)
fprintf(fid,'\n\nendval;\n');

switch switch_model    
    case 'ADS_SIR' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SIR_vars_end.' vars_names{ii} ');'])
        end;
    
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SIR_varexo_end.' varexo_names{ii} ');']);
        end;
        
    case 'ADS_SIS' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SIS_vars_end.' vars_names{ii} ');'])
        end;
        
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SIS_varexo_end.' varexo_names{ii} ');']);
        end;
    
    case 'ADS_SAIR' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SAIR_vars_end.' vars_names{ii} ');'])
        end;
    
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SAIR_varexo_end.' varexo_names{ii} ');']);
        end;
        
    case 'ADS_SIRS' 
        for ii=1:nn_vars
            eval(['fprintf(fid,''' vars_names{ii} '=%2.8f;\n'',' 'SIRS_vars_end.' vars_names{ii} ');'])
        end;
    
        for ii=1:nn_varexo
            eval(['fprintf(fid,''' varexo_names{ii} '=%2.8f;\n'',' 'SIRS_varexo_end.' varexo_names{ii} ');']);
        end;
end;

fprintf(fid,'end;\n');  %ending it


%Checking the solution and making dynare calculate the steady state
fprintf(fid,'\ncheck;');
fprintf(fid,'\nsteady;\n\n');


%Defining shocks values for Itilde
switch switch_model    
    case 'ADS_SIR' 
        xx=Y_SIR_eu(2:end,2);
        n_periods = size(Y_SIR_eu,1)-1;
    case 'ADS_SIS' 
        xx=Y_SIS_eu(2:end,2);
        n_periods = size(Y_SIS_eu,1)-1;
    case 'ADS_SAIR' 
        xx=Y_SAIR_eu(2:end,3);
        n_periods = size(Y_SAIR_eu,1)-1;
    case 'ADS_SIRS' 
        xx=Y_SIRS_eu(2:end,2);
        n_periods = size(Y_SIRS_eu,1)-1;
end;


%Printing trajectory
fprintf(fid,'xx=[');
fprintf(fid,'%.16f \n',xx);
fprintf(fid,'];\n');

%Defining shocks
fprintf(fid,'\nshocks;\n');
for ii=1:nn_varexo    
    eval(['fprintf(fid,''' 'var ' varexo_names{ii} ''  ';\n''' ');']);  
end;
 fprintf(fid,'periods 1:');
 fprintf(fid,'%d',n_periods);
 fprintf(fid,';\n');
 fprintf(fid,'values (xx);\n');
 fprintf(fid,'end;\n');


%Calling the solver
fprintf(fid,'\nperfect_foresight_setup(periods=');
fprintf(fid,'%d',n_periods);
fprintf(fid,');');
fprintf(fid,'\n//perfect_foresight_solver(lmmcp);');
fprintf(fid,'\nperfect_foresight_solver(maxit=100, tolf=1e-25, stack_solve_algo=0, linear_approximation);\n\n');

%Printing trajectories

%switch switch_model    
%    case 'ADS_SIR'
%        fprintf(fid,'rplot Itilde S Rtilde;\n');
%    case 'ADS_SIS'
%        fprintf(fid,'rplot Itilde S;\n');
%    case 'ADS_SAIR'
%        fprintf(fid,'rplot Itilde S Rtilde Atilde;\n');
%    case 'ADS_SIRS'
%        fprintf(fid,'rplot Itilde S Rtilde;\n');
%end

%fprintf(fid,'rplot Itilde;\n');
%fprintf(fid,'rplot L;\n');
%fprintf(fid,'rplot Y;\n');
%fprintf(fid,'rplot C K G In;\n');
%fprintf(fid,'rplot i R Rk Pm W b;\n');
%fprintf(fid,'rplot Pi;\n');
%fprintf(fid,'rplot Omega V Q_Z;\n');

%Write latex
fprintf(fid,'write_latex_dynamic_model;\n');

%Closing the dynare file
fclose(fid);
cd ..
