%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculating the no disease steady state
%This steady state assumes that L=1, but reajustes to changes in parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Order (risk_premium,leverage,zeta,omega,h)
%baseline US (0.01/4,4,0.5,10,0.71)
%baseline EU (0.01/4,4,0.5,10,0.591)


function baseline_ss = baseline_ss(eco)

%%%%%%%%%%%%%%%%%%%%
%Setting parameters
%%%%%%%%%%%%%%%%%%%%

%Epidemiological block
alphav=0.4;     % transmision rate
betav=0.2;      %asymptomatic transition rate
gammav=0.1;     % recovery rate
epsilonv=0.05;  % immunity (return to susceptible)

%Househods
betta   =   0.99;            %Discount rate
h      =   eco(5);            %Internal habit formation


%Targeted moments
    RkmR_mom =   eco(1);    %steady state premium
    phi_mom  =   eco(2);         %steady state leverage
    R_mom     = 1/betta;      %steady state of gros interest rate
    Lambda_mom =    betta;       %steady state of stochastic discount factor
    

%Credit policy parameters
tau     =   0.001;  %Efficient costs of credit policy
psi_bar  =  0;      %fraction of publicly intermediated assets 
omega   =   eco(4);     %feedback parameter
    
    
%Private banks
theta   =   0.975;     %The survival probability
lambda = (1-theta)*(phi_mom*Lambda_mom*RkmR_mom + Lambda_mom*R_mom) ...
    / (phi_mom*(1 - phi_mom*Lambda_mom*theta*RkmR_mom - Lambda_mom*theta*R_mom));  %share of diverting funds
epsilon = (1-psi_bar)*(1-theta*(RkmR_mom*phi_mom+R_mom))/((1-theta)*phi_mom); %share of startup funds

%Intermediate goods producers
alfa    =   0.33;           %Capital share
delta   =   0.025;          %Depreciation rate
omega_g     =   0.18;       %Government expenditures

%Capital producers
kappa   =   5.74;          %investment adjustment cost constant

%Retail firms
epsilon_p =   4.167;        %Elasticity of substitution between goods
theta_p   =   0.66;         %Calvo parameter
chi       =   0.24;         %Price indexation parameter
%theta_p   =   0.905;        %Calvo parameter
%chi       =   0.477;        %Price indexation parameter

%Monetary Policy and Government
zetta   =   0.5;            %share of unemployment benefit
phi_i   =   0.81;              %Interest rate smoothing parameter
phi_pi  =   2.04;              %Inflation coefficient
phi_y   =   0.08;              %Output gap coefficient
%phi_i   =   0.956;             %Interest rate smoothing parameter
%phi_pi  =   1.688;             %Inflation coefficient
%phi_y   =   0.098;             %Output gap coefficient

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculating Steady State
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Epidemiological block (everybody works)
L=1;

%Households
R   =   1/betta;
Lambda = betta;

%Targets
phi     =   phi_mom;
RkmR    =   RkmR_mom;

%Producers
Pi          =   1;
Q       =   1;
Pistar =   ((1-theta_p*Pi^((chi-1)*(1-epsilon_p)))/(1-theta_p))^(1/(1-epsilon_p));
vp      =   (1-theta_p*Pistar^(-epsilon_p))/(1-theta_p*Pi^(-epsilon_p*chi));
Pm  = (epsilon_p-1)/epsilon_p*Pistar*(1-betta*theta_p*Pi^((chi-1)*(1-epsilon_p)))/(1-betta*theta_p*Pi^((chi-1)*(-epsilon_p)));
K   =   (Q*(RkmR - (1-delta) + R)/(alfa*Pm*L^(1-alfa)))^(1/(alfa-1));
Ym  =   K^alfa*L^(1-alfa);
Y   =   Ym/vp;
In  =   delta*K;
G   =   omega_g*Y;
Rk  =   (alfa*Pm*Ym/K+(1-delta)*Q)/Q;
W   =   (1-alfa)*Pm*Ym/L;
C   =   (1-omega_g)*Y - delta*K - tau*psi_bar*K;
Z   =   K;
f   =   0;
fprime = 0;

%Government
b   =   zetta*W;
psi =   psi_bar;
i   =   R*Pi-1;

%Private banks
Gamma   =   1-theta + lambda*theta*phi;
eta     =   Lambda*Gamma*R;
nu      =   Lambda*Gamma*(RkmR);
Omega   =  (1-psi_bar)*Q*Z/phi;
V       =   nu*Q*Z + eta*Omega;
Q_Z     =   Q*Z;
V1      =   nu*Q*Z;
V2      =   eta*Omega;


%Rest
lambda_c = 1/(C*(1-h))*(1-betta*h);
g1  =   lambda_c*Ym*Pistar/(1-betta*theta_p*Pi^((chi-1)*(1-epsilon_p)));
g2  =   lambda_c*Ym*Pm/(1-betta*theta_p*Pi^((chi-1)*(-epsilon_p)));



%Creating cell array of variables
vars_cell   =   {'L';'C';'Z';'K';'Ym';'In';'Y';'R';'Rk';'Q';'Pm';'vp';'Pi'...
    ;'Pistar';'W';'b';'i';'lambda_c';'Lambda';'phi';'eta';'nu';'Omega';'Gamma';'f';'fprime';'g1';'g2'...
    ;'psi';'G';'V';'Q_Z';'V1';'V2'};
nn_vars     =   length(vars_cell);

%Creating a structure with the variables
nn_vars      =  length(vars_cell);
for ii=1:nn_vars
    eval(['vars.' vars_cell{ii} '=' vars_cell{ii} ';']);
end;

cd ..
save ./Graphs/Results/ss_O.mat vars;
